==========
socketscpi
==========


.. image:: https://img.shields.io/pypi/v/socketscpi.svg
        :target: https://pypi.python.org/pypi/socketscpi

.. image:: https://img.shields.io/travis/morgan-at-keysight/socketscpi.svg
        :target: https://travis-ci.org/morgan-at-keysight/socketscpi

.. image:: https://readthedocs.org/projects/socketscpi/badge/?version=latest
        :target: https://socketscpi.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

Current version: 2024.10.0

Tired of troubleshooting VISA connections, conflicts, and incompatibilities?

Need the fastest communication possible with your test equipment?

Try socketscpi: a robust and easy-to-use SCPI interface for electronic test and measurement equipment.

Socketscpi is a wrapper for Python's socket module. This removes the requirement for VISA and improves data transfer speed over the older VXI-11 protocol.

Features
--------
* Written using the socket module for fast communication
* Implements write, read, query, binary block read, binary block write


* Free software: MIT License
* Documentation: https://socketscpi.readthedocs.io/en/latest/index.html
